//
//  PlayerViewController.swift
//  AMPTVOSSample
//
//  Created by Cortes Saenz, David on 10/23/15.
//  Copyright © 2015 Akamai. All rights reserved.
//

import UIKit
import AVKit

import AmpCoreTV
import AmpMediaAnalyticsTV
import AmpOctoshapeTV
import AmpStatisticsTV

open class PlayerViewController: UIViewController, AVPlayerViewControllerDelegate, PlayerEventObserver, AmpOctoshapeObserver {
    
    open var ampPlayer: AmpPlayer!
    open var playerController: AVPlayerViewController = AVPlayerViewController()
    open var ampMA: AmpMediaAnalyticsManager!
    open var ampOctoshape: AmpOctoshapeManager!
    open var ampStatistics: AmpStatisticsManager!
    var time: Double!
    var playerId: Int!
    
    let octoSourceTitle = "Octoshape Source:"
    let maBeaconTitle = "Media Analytics Beacon:"
    
    let imaPreMidPostRoll = "http://pubads.g.doubleclick.net/gampad/ads?sz=640x480&iu=/124319096/external/ad_rule_samples&ciu_szs=300x250&ad_rule=1&impl=s&gdfp_req=1&env=vp&output=vmap&unviewed_position_start=1&cust_params=deployment%3Ddevsite%26sample_ar%3Dpremidpost&cmsid=496&vid=short_onecue&correlator="
    
    override open func viewDidLoad() {
        // super.viewDidLoad()
//        NSNotificationCenter.defaultCenter().addObserver(self, selector: Selector("appGoesToBackground:"), name:UIApplicationWillResignActiveNotification, object: nil)
//        NSNotificationCenter.defaultCenter().addObserver(self, selector: Selector("appCameBackFromBackground:"), name:UIApplicationDidBecomeActiveNotification, object: nil)
        
        let url = "http://multiformatlive-f.akamaihd.net/i/demostream_1@2131/master.m3u8"
    }
    
    override open func pressesEnded(_ presses: Set<UIPress>, with event: UIPressesEvent?) {
        for item in presses {
            if item.type == .playPause {
                print("PlayPause")
            }
        }
    }
    
//    func appGoesToBackground(notification : NSNotification) {
//        if let player = self.ampPlayer {
//            player.pause();
//            time = player.currentTime()
//        }
//    }
    
    func appCameBackFromBackground(_ notification : Notification) {
        self.ampPlayer.seekTo(self.time)
    }
    
    open func playerViewController(_ playerViewController: AVPlayerViewController, willResumePlaybackAfterUserNavigatedFrom oldTime: CMTime, to targetTime: CMTime) {
        self.ampMA.notifyEndScrub()
    }

    
    open func playVideo(_ videoUrl: String, playerController: AVPlayerViewController) {
        
        self.ampPlayer = AmpPlayer()
        self.ampPlayer.autoplay = true
        
        self.ampPlayer.setLicense("AwEm7pZvp53RWegXHgBO2rAnKwFGuEU7+3U9ro9U0Oog28jRBBPFAFBo/gymG5a41KmBfllPlxNymOuIgZeSmvs8NlVVitKzI+UfVq0d3h/u4pM2044a3tXXqQ5exrOJR6yoOuXkaO+aBo97g0nJ3SZ2VJURrryijEpgfyYW3Sa/EBmwfFMakZI+7sZ8ZaqgexyjLz5tL6bFu4m8uDmbAq8mSxtFQn6Yxp31LbEXRl49tQ==")
        
        print("Amp Version: \(self.ampPlayer.version)")
        
        self.setupPlayerController(playerController)
        
        // Register
        playerId = self.ampPlayer.registerObserver(self)
        
        self.ampOctoshape = AmpOctoshapeManager(ampPlayer: self.ampPlayer, enableLogs: true, container:self.playerController.view)
        self.ampOctoshape.registerObserver(self)
        
        self.ampStatistics = AmpStatisticsManager(ampPlayer: self.ampPlayer, parentView: self.playerController.view, containerFrame: self.playerController.view.frame)
        
        self.ampPlayer.handleUrl(videoUrl)
        
        let times = [2.0, 4.0, 6.0, 8.0]
        _ = CuepointManager(ampPlayer: self.ampPlayer, observer: self, times: times)
        
        self.setupAnalytics()
        
        self.ampStatistics.addSegment("Media Analytics Beacon:", info: self.ampMA.configUrl!)
        
    }
    
    func setupAnalytics() {
        let analyticsUrl = "https://ma1019-r.analytics.edgekey.net/config/beacon-8566.xml"
        
        let customData = [
            "title": "AKaMTitle",
            "category": "AKamCategory",
            "playerId": "AKAM AVPlayer playerId",
            "device": "AKAM AVPlayer device",
            "show": "AKAM AVPlayer$show"
        ]
        
        self.ampMA = AmpMediaAnalyticsManager(ampPlayer: self.ampPlayer!, configUrl: analyticsUrl, customDimensions: customData as [String : AnyObject])
    }
    
    func setupPlayerController(_ playerController: AVPlayerViewController) {
        self.playerController = playerController
        
        self.playerController.delegate = self
        self.playerController.player = self.ampPlayer.player
        self.playerController.view.frame = self.view.frame
        self.addChildViewController(self.playerController)
        self.view.addSubview(self.playerController.view)
    }
    
    override open func didReceiveMemoryWarning() {
        // super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    open func onPlaybackStateChanged(_ ampPlayer: AmpPlayer) {
        //        print("onPlaybackStateChanged")
        if (ampPlayer.playbackState == PlaybackState.failed) {
            // Handle error
        }
    }
    
    open func onBufferingStateChanged(_ ampPlayer: AmpPlayer) {
        //        print("onBufferingStateChanged")
        if (ampPlayer.bufferingState == BufferingState.ready) {
            
//            self.ampPlayer.play()
            
            print("BufferingState.Ready")
        }
    }
    
    open func onError(_ ampPlayer: AmpPlayer, error: PlayerError) {
        switch(error) {
        case PlayerError.unknownAssetFormat(let assetUrl):
            print("PlayerError.UnknownAssetFormat: ", assetUrl)
        case PlayerError.downloadFailed():
            print("PlayerError.DownloadFailed")
        case PlayerError.unknownError(let message):
            print("PlayerError.UnknownError: ", message)
        }
    }
    
    open func onPositionChange(_ ampPlayer: AmpPlayer) {
        //        print("time: %d", ampPlayer.currentTime())
    }
    
    open func onCuepointReached(_ ampPlayer: AmpPlayer, atTime: Double) {
        print("cuepoint: %d - time: %d", atTime, ampPlayer.currentTime())
    }
    
    open func onCurrentStreamInfoEvent(_ currentStream: OCCurrentStreamInfoEvent) {
        print("CurrentStreamInfo - bitrate: %d", currentStream.rateset)
        self.ampStatistics.updateSegment(AmpStatisticsManager.bitrateTitle, info: AmpStatisticsManager.formatBitrate(Double(currentStream.rateset)))
        
    }
    
    open func onStreamInformationChanged(_ ampPlayer: AmpPlayer, streamInfo: StreamInfo) {
        
    }
    
    open func onMultiStreamInfoEvent(_ multiStream: OCMultiStreamInfoEvent) {
        multiStream.baseStreams.map({stream in stream as! NSDictionary})
            .forEach { print("Stream:%@ - bitrate: %@, channel: %@", String(describing: $0), $0["bitrate"], $0["name"]) }
    }
    
    open func onStreamSourceInfoEvent(_ streamSource: OCStreamSourceInfoEvent) {
        if let streamSource = streamSource.streamSource {
            print("Source: ", streamSource)
            if self.ampStatistics.hasSegment(octoSourceTitle) {
                self.ampStatistics.updateSegment(octoSourceTitle, info: streamSource)
            } else {
                self.ampStatistics.addSegment(octoSourceTitle, info: streamSource)
            }
        }
        
        if let multiCastStatus = streamSource.multiCastStatus {
            print("MultiCast Status: ", multiCastStatus)
        }
    }
    
    // When we go back to collection view
    override open func viewWillDisappear(_ animated:Bool) {
        self.ampPlayer.stop()
        self.ampPlayer = nil
        print("Stopped")
        self.playerController.player = nil
        super.viewWillDisappear(animated)
    }
    
}

